Package: retistruct
License: CC BY-NC-SA 4.0
Title: Retinal Reconstruction Program
Authors@R: c(person(c("David", "C."), "Sterratt", role=c("aut", "cre", "cph"),
    email="david.c.sterratt@ed.ac.uk"), person("Daniel", "Lyngholm",
    role=c("aut", "cph")), person("Jan", "Okul", role=c("aut", "cph")))
Description: Reconstructs retinae by morphing a flat surface with cuts
    (a dissected flat-mount retina) onto a curvilinear surface (the
    standard retinal shape). It can estimate the position of a point
    on the intact adult retina to within 8 degrees of arc (3.6% of
    nasotemporal axis). The coordinates in reconstructed retinae can
    be transformed to visuotopic coordinates. For more details see
    Sterratt, D. C., Lyngholm, D., Willshaw, D. J. and Thompson, I. D.
    (2013) <doi:10.1371/journal.pcbi.1002921>.
Version: 0.8.1
URL: http://davidcsterratt.github.io/retistruct/
BugReports: https://github.com/davidcsterratt/retistruct/issues
Date: 2025-06-07
Depends: R (>= 3.5.0)
Imports: foreign, RImageJROI, png, ttutils, sp, geometry (>= 0.4.3),
        RTriangle (>= 1.6-0.15), rgl, R.matlab, R6, tiff, shiny,
        shinyjs, shinyFiles, bslib, fs
Suggests: spelling, testthat
Language: en-GB
RoxygenNote: 7.3.2
Encoding: UTF-8
NeedsCompilation: yes
Packaged: 2025-06-07 16:34:31 UTC; dcs
Author: David C. Sterratt [aut, cre, cph],
  Daniel Lyngholm [aut, cph],
  Jan Okul [aut, cph]
Maintainer: David C. Sterratt <david.c.sterratt@ed.ac.uk>
Repository: CRAN
Date/Publication: 2025-06-08 09:10:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-29 07:11:24 UTC; unix
Archs: retistruct.so.dSYM
