# Generated by roxygen2: do not edit by hand

S3method(depthplot3D,TriangulatedOutline)
S3method(depthplot3D,default)
S3method(flatplot,AnnotatedOutline)
S3method(flatplot,CountSet)
S3method(flatplot,LandmarkSet)
S3method(flatplot,Outline)
S3method(flatplot,PathOutline)
S3method(flatplot,PointSet)
S3method(flatplot,ReconstructedOutline)
S3method(flatplot,RetinalOutline)
S3method(flatplot,StitchedOutline)
S3method(flatplot,TriangulatedOutline)
S3method(flatplot,default)
S3method(lvsLplot,ReconstructedOutline)
S3method(lvsLplot,default)
S3method(projection,ReconstructedCountSet)
S3method(projection,ReconstructedLandmarkSet)
S3method(projection,ReconstructedOutline)
S3method(projection,ReconstructedPointSet)
S3method(projection,RetinalReconstructedOutline)
S3method(projection,default)
S3method(sphericalplot,ReconstructedOutline)
S3method(sphericalplot,ReconstructedPointSet)
S3method(sphericalplot,RetinalReconstructedOutline)
S3method(sphericalplot,default)
export(AnnotatedOutline)
export(CountSet)
export(FeatureSet)
export(FeatureSetCommon)
export(LandmarkSet)
export(PathOutline)
export(PointSet)
export(ReconstructedCountSet)
export(ReconstructedFeatureSet)
export(ReconstructedLandmarkSet)
export(ReconstructedOutline)
export(ReconstructedPointSet)
export(RetinalOutline)
export(RetinalReconstructedOutline)
export(StitchedOutline)
export(TriangulatedFragment)
export(TriangulatedOutline)
export(azel.to.sphere.colatitude)
export(azimuthal.conformal)
export(azimuthal.equalarea)
export(azimuthal.equidistant)
export(bary.to.sphere.cart)
export(central.angle)
export(checkDatadir)
export(compute.kernel.estimate)
export(create.polar.cart.grid)
export(depthplot3D)
export(flatplot)
export(identity.transform)
export(idt.read.dataset)
export(invert.sphere)
export(invert.sphere.to.hemisphere)
export(karcher.mean.sphere)
export(kde.L)
export(kde.compute.concentration)
export(kde.fhat)
export(kde.fhat.cart)
export(kr.compute.concentration)
export(kr.sscv)
export(kr.yhat)
export(kr.yhat.cart)
export(line.line.intersection)
export(list.datasets)
export(lvsLplot)
export(morph.dataset.to.parabola)
export(normalise.angle)
export(orthographic)
export(panlabel)
export(polar.cart.to.sphere.spherical)
export(polartext)
export(projection)
export(remove.intersections)
export(report)
export(retistruct)
export(retistruct.batch)
export(retistruct.batch.export.matlab)
export(retistruct.batch.figures)
export(retistruct.batch.get.titrations)
export(retistruct.batch.plot.titrations)
export(retistruct.batch.summary)
export(retistruct.check.markup)
export(retistruct.cli)
export(retistruct.cli.figure)
export(retistruct.cli.process)
export(retistruct.export.matlab)
export(retistruct.read.dataset)
export(retistruct.read.markup)
export(retistruct.read.recdata)
export(retistruct.reconstruct)
export(retistruct.save.markup)
export(retistruct.save.recdata)
export(rotate.axis)
export(sinusoidal)
export(sphere.cart.to.sphere.dualwedge)
export(sphere.cart.to.sphere.spherical)
export(sphere.cart.to.sphere.wedge)
export(sphere.spherical.to.polar.cart)
export(sphere.tri.area)
export(sphere.wedge.to.sphere.cart)
export(sphericalplot)
export(tri.area)
export(tri.area.signed)
export(vecnorm)
import(rgl, except = triangulate)
import(shiny)
import(shinyFiles)
import(ttutils)
importFrom(R6,R6Class)
importFrom(RTriangle,pslg)
importFrom(bslib,nav_panel)
importFrom(bslib,navset_tab)
importFrom(fs,path_home)
importFrom(geometry,Unique)
importFrom(geometry,bary2cart)
importFrom(geometry,delaunayn)
importFrom(geometry,dot)
importFrom(geometry,sph2cart)
importFrom(geometry,trimesh)
importFrom(geometry,tsearch)
importFrom(grDevices,dev.copy2pdf)
importFrom(grDevices,dev.cur)
importFrom(grDevices,dev.off)
importFrom(grDevices,dev.set)
importFrom(grDevices,jpeg)
importFrom(grDevices,palette)
importFrom(grDevices,pdf)
importFrom(grDevices,png)
importFrom(grDevices,rainbow)
importFrom(grDevices,svg)
importFrom(grDevices,tiff)
importFrom(graphics,abline)
importFrom(graphics,arrows)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,rasterImage)
importFrom(graphics,segments)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(shiny,observeEvent)
importFrom(shiny,renderPlot)
importFrom(shiny,renderText)
importFrom(shiny,shinyApp)
importFrom(shinyFiles,shinyDirButton)
importFrom(shinyFiles,shinySaveButton)
importFrom(shinyjs,delay)
importFrom(shinyjs,disable)
importFrom(shinyjs,enable)
importFrom(shinyjs,useShinyjs)
importFrom(stats,na.omit)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,uniroot)
importFrom(utils,capture.output)
importFrom(utils,read.csv)
importFrom(utils,write.csv)
useDynLib(retistruct)
